# Generated by ariadne-codegen on 2023-06-16 04:37
# Source: queries

from typing import List

from pydantic import Field

from .base_model import BaseModel


class TopPopularIPs(BaseModel):
    top_popular_i_ps: "TopPopularIPsTopPopularIPs" = Field(alias="topPopularIPs")


class TopPopularIPsTopPopularIPs(BaseModel):
    query_info: "TopPopularIPsTopPopularIPsQueryInfo" = Field(alias="queryInfo")
    popular_i_ps: List["TopPopularIPsTopPopularIPsPopularIPs"] = Field(
        alias="popularIPs"
    )


class TopPopularIPsTopPopularIPsQueryInfo(BaseModel):
    results_available: int = Field(alias="resultsAvailable")
    results_limit: int = Field(alias="resultsLimit")


class TopPopularIPsTopPopularIPsPopularIPs(BaseModel):
    ip: str
    request_count: int
    users_count: int


TopPopularIPs.update_forward_refs()
TopPopularIPsTopPopularIPs.update_forward_refs()
TopPopularIPsTopPopularIPsQueryInfo.update_forward_refs()
TopPopularIPsTopPopularIPsPopularIPs.update_forward_refs()
