# Generated by ariadne-codegen on 2023-06-16 04:37
# Source: queries

from typing import Any, List

from pydantic import Field

from .base_model import BaseModel


class TopKnocks(BaseModel):
    top_knocks: "TopKnocksTopKnocks" = Field(alias="topKnocks")


class TopKnocksTopKnocks(BaseModel):
    query_info: "TopKnocksTopKnocksQueryInfo" = Field(alias="queryInfo")
    knock: List["TopKnocksTopKnocksKnock"]


class TopKnocksTopKnocksQueryInfo(BaseModel):
    results_available: int = Field(alias="resultsAvailable")
    results_limit: int = Field(alias="resultsLimit")


class TopKnocksTopKnocksKnock(BaseModel):
    tor_exit: bool
    title: str
    source_ip: str
    links: List[str]
    last_seen: Any
    last_crawled: Any
    knock_port: int
    jarm: str
    ips: List[str]
    headers: str
    favicon_mmh3_32: int
    favicon_mmh3_128: str
    emails: List[str]
    apps: str


TopKnocks.update_forward_refs()
TopKnocksTopKnocks.update_forward_refs()
TopKnocksTopKnocksQueryInfo.update_forward_refs()
TopKnocksTopKnocksKnock.update_forward_refs()
